==> dinolib-0.9.3.tar.gz: dinolib-0.9.3/lib/form/of_checkbox2.inc.php <==
<?php
/* OOHForms: checkbox 2 ( for multiple )
 *
 * Copyright (c) 1998 by Jay Bloodworth
 *
 * $Id: of_checkbox2.inc.php,v 1.1 2003/03/31 06:04:07 tumf Exp $
 */

class of_checkbox2 extends of_element {

  var $options;
  var $size;
  var $valid_e;

  // Constructor
  function of_checkbox2($a) {
    $this->setup_element($a);
    if ($a["type"]=="checkbox2") $this->multiple=1;
  }
  
  function self_get($val,$which, &$count) {
    $str = "";
    
    //    if ($this->multiple) {
    $n = $this->name . "[]";
    //	$t = "<input type=checkbox";
    //    } else {
    //	$n = $this->name;
    //	$t = "checkbox";
    //    }
    //    $str .= "<$t name='$n'";
    //    #if ($this->size) 
    //    #  $str .= " size='$this->size'";
    //    if ($this->extrahtml) 
    //	$str .= " $this->extrahtml";
    //    #$str .= ">";

    reset($this->options);
    while (list($k,$o) = each($this->options)) {
      $str .= "<input type=checkbox name=$n";

      if (is_array($o)) {
	$ov = $o["value"];
        $str .= " value='" .  $ov . "'";
      } else {
	$ov = $o;
      }

      if (!$this->multiple && isset($this->value) && $this->value==$ov)
	$str .= " checked";
      elseif ($this->multiple && is_array($this->value)) {
        reset($this->value);
	while (list($tk,$v) = each($this->value)) {
	  if ($v==$ov) { 
	    $str .= " checked"; break; 
	  }
	}
      }
      $str .= ">" . (is_array($o) ? $o["label"] : $o) . "\n";
    }
    
    $count = 1;
    return $str;
  }

  function self_get_frozen($val,$which, &$count) {
    $str = "";
    
    $x = 0;
    $n = $this->name . ($this->multiple ? "[]" : "");
    $v_array = (is_array($this->value) ? $this->value : array($this->value));

    /*
      $str .= "<table border=1>\n";
      reset($v_array);
      while (list($tk,$tv) = each($v_array)) {
      reset($this->options);
      while (list($k,$v) = each($this->options)) {
      if ((is_array($v) && 
      (($tmp=$v["value"])==$tv || $v["label"]==$tv))
      || ($tmp=$v)==$tv) {
      $x++;
      $str .= "<input type='hidden' name='$n' value='$tmp'>\n";
      $str .= "<tr><td>" . (is_array($v) ? $v["label"] : $v) . "</td></tr>\n";
      }
      }
      }
      $str .= "</table>\n";
    */

    // not table 
    reset($v_array);
    while (list($tk,$tv) = each($v_array)) {
      reset($this->options);
      while (list($k,$o) = each($this->options)) {
	if (is_array($o)) $ov = $o["value"];
	else $ov = $o;
        if ($ov==$tv) {
          $x++;
          $str .= "<input type='hidden' name='$n' value='$ov'>\n";
          $str .= (is_array($o) ? $o["label"] : $o) . "\n";
        }
      }
    }


    $count = $x;
    return $str;
  }

  function self_get_js($ndx_array) {
    $str = "";
    
    if (!$this->multiple && $this->valid_e) {
      $str .= "if (f.$this->name.selectedIndex == 0) {\n";
      $str .= "  alert(\"$this->valid_e\");\n";
      $str .= "  f.$this->name.focus();\n";
      $str .= "  return(false);\n";
      $str .= "}\n";
    }
    
    return $str;
  }

  function self_validate($val) {
    if (!$this->multiple && $this->valid_e) {
      reset($this->options);
      $o = current($this->options);
      if (is_array($o)) $ov = $o["value"];
      else $ov = $o;
      if ($val==$ov) return $this->valid_e;
    }
    return false;
  }

} // end SELECT

?>

==> dinolib-0.9.4a.tar.gz: dinolib-0.9.4a/lib/form/of_checkbox2.inc.php <==
<?php
/* OOHForms: checkbox 2 ( for multiple )
 *
 * Copyright (c) 1998 by Jay Bloodworth
 *
 * $Id: of_checkbox2.inc.php,v 1.3 2003/08/25 08:01:07 kasugai Exp $
 */

class of_checkbox2 extends of_element {

  var $options;
  var $size;
  var $valid_e;

  // Constructor
  function of_checkbox2($a) {
    $this->setup_element($a);
    if ($a["type"]=="checkbox2") $this->multiple=1;
  }
  
  function self_get($val,$which, &$count) {
    $str = "";
    
    //    if ($this->multiple) {
    $n = $this->name . "[]";
    //	$t = "<input type=checkbox";
    //    } else {
    //	$n = $this->name;
    //	$t = "checkbox";
    //    }
    //    $str .= "<$t name='$n'";
    //    #if ($this->size) 
    //    #  $str .= " size='$this->size'";
    //    if ($this->extrahtml) 
    //	$str .= " $this->extrahtml";
    //    #$str .= ">";
    
    if(is_array($_REQUEST[$this->name])){$this->value = $_REQUEST[$this->name];}
    //optionsꤵƤʤȥ
    if($this->options){
      reset($this->options);
      while (list($k,$o) = each($this->options)) {
	$str .= "<input type=checkbox name=$n";
	
	if (is_array($o)) {
	  $ov = $o["value"];
	  $str .= " value='" .  $ov . "'";
	} else {
	  $ov = $o;
	}
      
	if (!$this->multiple && isset($this->value) && $this->value==$ov)
	  $str .= " checked";
	elseif ($this->multiple && is_array($this->value)) {
	  reset($this->value);
	  while (list($tk,$v) = each($this->value)) {
	    if ($v==$ov) { 
	      $str .= " checked"; break; 
	    }
	  }
	}
	$str .= ">" . (is_array($o) ? $o["label"] : $o) . "\n";
      }
    }else{
      $str .= "<font color='red'>No label. Must be append.</font>";
    }
    
    $count = 1;
    return $str;
  }

  function self_get_frozen($val,$which, &$count, $hidden = false) {
    $str = "";
    $x = 0;
    $n = $this->name . ($this->multiple ? "[]" : "");

    $this->value = $_REQUEST[$this->name];    
    $v_array = (is_array($this->value) ? $this->value : array($this->value));

    /*
      $str .= "<table border=1>\n";
      reset($v_array);
      while (list($tk,$tv) = each($v_array)) {
      reset($this->options);
      while (list($k,$v) = each($this->options)) {
      if ((is_array($v) && 
      (($tmp=$v["value"])==$tv || $v["label"]==$tv))
      || ($tmp=$v)==$tv) {
      $x++;
      $str .= "<input type='hidden' name='$n' value='$tmp'>\n";
      $str .= "<tr><td>" . (is_array($v) ? $v["label"] : $v) . "</td></tr>\n";
      }
      }
      }
      $str .= "</table>\n";
    */

    // not table 
    reset($v_array);
    while (list($tk,$tv) = each($v_array)) {
      reset($this->options);
      while (list($k,$o) = each($this->options)) {
	if (is_array($o)) $ov = $o["value"];
	else $ov = $o;
        if ($ov==$tv) {
          $x++;
          $str .= "<input type='hidden' name='$n' value='$ov'>\n";
	  if($hidden){
	    // never output *visible* HTML
	  }else{
	    $str .= (is_array($o) ? $o["label"] : $o) . "\n";
	  }
        }
      }
    }


    $count = $x;
    return $str;
  }

  function self_get_js($ndx_array) {
    $str = "";
    
    if (!$this->multiple && $this->valid_e) {
      $str .= "if (f.$this->name.selectedIndex == 0) {\n";
      $str .= "  alert(\"$this->valid_e\");\n";
      $str .= "  f.$this->name.focus();\n";
      $str .= "  return(false);\n";
      $str .= "}\n";
    }
    
    return $str;
  }

  function self_validate($val) {
    if (!$this->multiple && $this->valid_e) {
      reset($this->options);
      $o = current($this->options);
      if (is_array($o)) $ov = $o["value"];
      else $ov = $o;
      if ($val==$ov) return $this->valid_e;
    }
    return false;
  }

} // end SELECT

?>
